==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/igr-radial-pie-series.js <==
import { __extends } from "tslib";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
var IgrRadialPieSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialPieSeries, _super);
    function IgrRadialPieSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialPieSeries.prototype.createImplementation = function () {
        return new RadialPieSeries();
    };
    Object.defineProperty(IgrRadialPieSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "isPie", {
        /**
         * Gets whether the current series shows a pie shape.
        */
        get: function () {
            return this.i.e0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.ey;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ya;
        },
        set: function (v) {
            this.i.ya = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.yb;
        },
        set: function (v) {
            this.i.yb = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialPieSeries.prototype.getItemSpan = function () {
        var iv = this.i.h0();
        return (iv);
    };
    return IgrRadialPieSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialPieSeries };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/igr-radial-pie-series.js <==
import { __extends } from "tslib";
import { LegendEmptyValuesMode_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
import { ensureEnum, toPoint, fromRect } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
var IgrRadialPieSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialPieSeries, _super);
    function IgrRadialPieSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialPieSeries.prototype.createImplementation = function () {
        return new RadialPieSeries();
    };
    Object.defineProperty(IgrRadialPieSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "isPie", {
        /**
         * Gets whether the current series shows a pie shape.
        */
        get: function () {
            return this.i.fm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.fk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.adq;
        },
        set: function (v) {
            this.i.adq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.adr;
        },
        set: function (v) {
            this.i.adr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "legendLabelMemberPath", {
        /**
         * Gets or sets the property name that contains the legend labels.
        */
        get: function () {
            return this.i.adv;
        },
        set: function (v) {
            this.i.adv = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialPieSeries.prototype, "legendEmptyValuesMode", {
        /**
         * Determines display mode for zero values in the legend.
        */
        get: function () {
            return this.i.adl;
        },
        set: function (v) {
            this.i.adl = ensureEnum(LegendEmptyValuesMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialPieSeries.prototype.getItemSpan = function () {
        var iv = this.i.iv();
        return (iv);
    };
    IgrRadialPieSeries.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.wj(toPoint(world));
        return fromRect(iv);
    };
    return IgrRadialPieSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialPieSeries };
